package ij.plugin.filter;

import java.awt.*;
import java.awt.image.*;
import java.util.Vector;
import java.io.*;
import ij.*;
import ij.process.*;
import ij.io.*;


/**Writes the XY coordinates of all black pixels in the active image to a text file.*/
public class XY_Coordinates implements PlugInFilter {

	ImagePlus imp;

	public int setup(String arg, ImagePlus imp) {
		this.imp = imp;
		return DOES_8G;
	}

	public void run(ImageProcessor ip) {
		int width = imp.getWidth();
		int height = imp.getHeight();
		int[] pixel = imp.getPixel(0, 0);
		int black = 255-pixel[0];
		imp.killRoi();
		
		boolean okay = IJ.showMessageWithCancel("XY_Coordinates", 
			"This plug-in writes the XY coordinates of all\n"
			+ "black pixels in the active image to a text file.\n"
			+ "The pixel value used for black is determined by\n"
			+ "subtracting the value of the pixel at (0,0) from 255.\n"
			+ " \n"
			+ "width: " + width + "\n"
			+ "height: " + height + "\n"
			+ "assumed value for black: " + black + "\n"
			);
		if (!okay)
			return;
				
		SaveDialog sd = new SaveDialog("Save Coordinates as Text...", imp.getTitle(), ".txt");
		String name = sd.getFileName();
		if (name == null)
			return;
		String directory = sd.getDirectory();
		PrintWriter pw = null;
		try {
			FileOutputStream fos = new FileOutputStream(directory+name);
			BufferedOutputStream bos = new BufferedOutputStream(fos);
			pw = new PrintWriter(bos);
		}
		catch (IOException e) {
			IJ.write("" + e);
			return;
		}

		IJ.showProgress(0);
		IJ.wait(250);  // give system time to redraw ImageJ window
		IJ.showStatus("Saving coordinates...");
		int count = 0;
		byte[] pixels = (byte[])ip.getPixels();
		String ls = System.getProperty("line.separator");
		for (int y=height-1; y>=0; y--) {
			for (int x=0; x<width; x++)
				if ((pixels[y*width+x]&0xff)==black) {
					pw.print(x + " " + (height-1-y) + ls);
					count++;
				}
			if (y%10==0) IJ.showProgress((double)(height-y)/height);
		}
		IJ.showProgress(1.0);
		pw.close();
		IJ.write(imp.getTitle() + ": " + count + " black pixels (" + (count*100/(width*height)) + "%)\n");
	}

	void setFile(FileDialog fd, String name, String extension) {
		if (name.charAt(name.length()-4)=='.')
			name = name.substring(0, name.length()-4);
		name += extension;
		fd.setFile(name);
	}

}
